.. seealso::

    `User Mailing List <https://www.redhat.com/mailman/listinfo/linchpin>`_
        Subscribe and participate. A great place for Q&A
    `LinchPin on Github <https://github.com/CentOS-PaaS-SIG/linchpin>`_
        Code Contributions and Latest Software
    `webchat.freenode.net <http://webchat.freenode.net?channels=linchpin>`_
        #linchpin IRC chat channel
    `LinchPin on PyPi <https://pypi.org/project/linchpin/>`_
        Latest Release of LinchPin

